@@ -786,6 +786,9 @@ class TestConfig(object):
             "log_level": "INFO",
             "retention_policy": "redundancy 2",
             "wal_retention_policy": "base",
+            "barman_lock_directory": "/some/barman/home",
+            "config_changes_queue": "/some/barman/home/cfg_changes.queue",
+            "lock_directory_cleanup": "true",
         }
         c = testing_helpers.build_config_from_dicts(global_conf=global_conf)
 
@@ -800,6 +803,9 @@ class TestConfig(object):
             "barman_user": "barman",
             "log_file": "/some/barman/home/log/barman.log",
             "archiver": "True",
+            "barman_lock_directory": "/some/barman/home",
+            "config_changes_queue": "/some/barman/home/cfg_changes.queue",
+            "lock_directory_cleanup": True,
         }
         assert c.global_config_to_json(False) == expected
 
@@ -1052,6 +1058,9 @@ class TestServerConfig(object):
             "log_level": "INFO",
             "retention_policy": "redundancy 2",
             "wal_retention_policy": "base",
+            "barman_lock_directory": "some",
+            "config_changes_queue": "some",
+            "lock_directory_cleanup": "true",
         }
         main_conf = {
             "active": "true",
@@ -1103,6 +1112,17 @@ class TestServerConfig(object):
         expected = testing_helpers.build_config_dictionary(expected_override)
         for key in ["config", "_active_model_file", "active_model"]:
             del expected[key]
+        # Remove field that is not needed or is not part of a server specific config.
+        for key in [
+            "barman_home",
+            "barman_lock_directory",
+            "config_changes_queue",
+            "lock_directory_cleanup",
+            "msg_list",
+            "name",
+        ]:
+            del expected[key]
+
         assert main.to_json(False) == expected
 
         # Check `to_json(with_source=True)` works as expected
@@ -1393,6 +1413,7 @@ class TestModelConfig:
             "last_backup_maximum_age": None,
             "last_backup_minimum_size": None,
             "last_wal_maximum_age": None,
+            "combine_mode": None,
             "local_staging_path": None,
             "max_incoming_wals_queue": None,
             "minimum_redundancy": None,
@@ -1499,6 +1520,7 @@ class TestModelConfig:
             "last_backup_maximum_age": {"source": "SOME_SOURCE", "value": None},
             "last_backup_minimum_size": {"source": "SOME_SOURCE", "value": None},
             "last_wal_maximum_age": {"source": "SOME_SOURCE", "value": None},
+            "combine_mode": {"source": "SOME_SOURCE", "value": None},
             "local_staging_path": {"source": "SOME_SOURCE", "value": None},
             "max_incoming_wals_queue": {"source": "SOME_SOURCE", "value": None},
             "minimum_redundancy": {"source": "SOME_SOURCE", "value": None},
@@ -1816,6 +1838,14 @@ class TestCsvParsing(object):
         test case
         global value: recovery_options = 'get-wal'
         expected: recovery_options = empty RecoveryOptions obj
+
+        test case
+        global value: recovery_options = 'delta-restore'
+        expected: recovery_options = empty RecoveryOptions obj
+
+        test case
+        global value: recovery_options = 'delta-restore,get-wal'
+        expected: recovery_options = empty RecoveryOptions obj
         """
         # Build configuration with empty recovery_options
         c = testing_helpers.build_config_from_dicts(
@@ -1846,12 +1876,42 @@ class TestCsvParsing(object):
         )
         assert main.__dict__ == expected
 
+        # Build configuration with recovery_options set to get-wal
+        c = testing_helpers.build_config_from_dicts(
+            global_conf={"archiver": "on", "recovery_options": "delta-restore"},
+            main_conf=None,
+        )
+        main = c.get_server("main")
+
+        expected = testing_helpers.build_config_dictionary(
+            {
+                "config": c,
+                "recovery_options": RecoveryOptions("delta-restore", "", ""),
+            }
+        )
+        assert main.__dict__ == expected
+
+        # Build configuration with recovery_options set to get-wal
+        c = testing_helpers.build_config_from_dicts(
+            global_conf={"archiver": "on", "recovery_options": "delta-restore,get-wal"},
+            main_conf=None,
+        )
+        main = c.get_server("main")
+
+        expected = testing_helpers.build_config_dictionary(
+            {
+                "config": c,
+                "recovery_options": RecoveryOptions("delta-restore,get-wal", "", ""),
+            }
+        )
+        assert main.__dict__ == expected
+
     def test_recovery_option_parser(self):
         """
         Test of the RecoveryOptions class.
 
         Builds the class using '', then using
-        'get-wal' as values.
+        'get-wal' and 'delta-restore' as values.
         Tests for ValueError conditions
         """
         # Builds using the two allowed values
@@ -1859,6 +1919,9 @@ class TestCsvParsing(object):
         assert set([RecoveryOptions.GET_WAL]) == RecoveryOptions(
             RecoveryOptions.GET_WAL, "", ""
         )
+        assert set([RecoveryOptions.DELTA_RESTORE]) == RecoveryOptions(
+            RecoveryOptions.DELTA_RESTORE, "", ""
+        )
         # build using a not allowed value
         with pytest.raises(ValueError):
             BackupOptions("test_string", "", "")
