@@ -82,35 +82,44 @@ EXPECTED_MINIMAL = {
             "parent_backup_id": None,
             "children_backup_ids": None,
             "cluster_size": 2048,
+            "encryption": None,
         }
     },
     "config": {},
     "last_name": "000000010000000000000005",
-    "last_position": 209,
+    "last_position": 229,
     "wals": [
         {
             "time": 1406019026.0,
             "size": 16777216,
             "compression": None,
+            "encryption": None,
             "name": "000000010000000000000002",
+            "encryption": None,
         },
         {
             "time": 1406019026.0,
             "size": 16777216,
             "compression": None,
+            "encryption": None,
             "name": "000000010000000000000003",
+            "encryption": None,
         },
         {
             "time": 1406019329.9300001,
             "size": 16777216,
             "compression": None,
+            "encryption": None,
             "name": "000000010000000000000004",
+            "encryption": None,
         },
         {
             "time": 1406019330.84,
             "size": 16777216,
             "compression": None,
+            "encryption": None,
             "name": "000000010000000000000005",
+            "encryption": None,
         },
     ],
     "version": barman.__version__,
@@ -189,11 +198,11 @@ class TestSync(object):
         # Create a test xlog.db
         tmp_path = tmpdir.join("xlog.db")
         tmp_path.write(
-            "000000010000000000000001\t16777216\t1406019022.4\tNone\n"
-            "000000010000000000000002\t16777216\t1406019026.0\tNone\n"
-            "000000010000000000000003\t16777216\t1406019026.0\tNone\n"
-            "000000010000000000000004\t16777216\t1406019329.93\tNone\n"
-            "000000010000000000000005\t16777216\t1406019330.84\tNone\n"
+            "000000010000000000000001\t16777216\t1406019022.4\tNone\tNone\n"
+            "000000010000000000000002\t16777216\t1406019026.0\tNone\tNone\n"
+            "000000010000000000000003\t16777216\t1406019026.0\tNone\tNone\n"
+            "000000010000000000000004\t16777216\t1406019329.93\tNone\tNone\n"
+            "000000010000000000000005\t16777216\t1406019330.84\tNone\tNone\n"
         )
 
         # Build a server, replacing some function to use the tmpdir objects
@@ -679,10 +688,10 @@ class TestSync(object):
         assert err == ""
         # check the xlog content for primary.info wals
         exp_xlog = [
-            "000000010000000000000002\t16777216\t1406019026.0\tNone\n",
-            "000000010000000000000003\t16777216\t1406019026.0\tNone\n",
-            "000000010000000000000004\t16777216\t1406019329.93\tNone\n",
-            "000000010000000000000005\t16777216\t1406019330.84\tNone\n",
+            "000000010000000000000002\t16777216\t1406019026.0\tNone\tNone\n",
+            "000000010000000000000003\t16777216\t1406019026.0\tNone\tNone\n",
+            "000000010000000000000004\t16777216\t1406019329.93\tNone\tNone\n",
+            "000000010000000000000005\t16777216\t1406019330.84\tNone\tNone\n",
         ]
         with server.xlogdb() as fxlogdb:
             xlog = fxlogdb.readlines()
